@@ -1,26 +1,18 @@
 pub use reqwasm::http::{Request, Response};
 
-use serde::de::DeserializeOwned;
+use serde::de::{Deserialize, DeserializeOwned, Deserializer};
 
 use crate::error::{Error, Result};
 
 #[derive(Copy, Clone)]
 pub struct MissingBody;
 
-trait Missing {
-    fn missing() -> Option<Self>
+impl<'de> Deserialize<'de> for MissingBody {
+    fn deserialize<D>(_deserializer: D) -> std::result::Result<Self, D::Error>
     where
-        Self: Sized,
+        D: Deserializer<'de>,
     {
-        None
-    }
-}
-
-impl<T: DeserializeOwned> Missing for T {}
-
-impl Missing for MissingBody {
-    fn missing() -> Option<Self> {
-        Some(Self)
+        Ok(Self)
     }
 }
 
@@ -70,11 +62,7 @@ impl JsonFetcher {
 async fn fetch_json<Body: DeserializeOwned>(request: Request) -> Result<(Response, Body)> {
     let response = request.send().await?;
     if response.status() == 200 {
-        let body = if let Some(body) = Body::missing() {
-            body
-        } else {
-            response.json().await?
-        };
+        let body = response.json().await?;
         Ok((response, body))
     } else {
         Err(Error::FailureResponse(
